@@ -30,7 +30,7 @@
 #include <gal/util/e-i18n.h>
 
 #define PARENT_TYPE E_TABLE_MODEL_TYPE
-ETableModelClass *parent_class;
+static ETableModelClass *parent_class;
 
 /*
  * ECategoriesMasterListDialogModel callbacks
